# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2021-2024, by Samuel Williams.

source "https://rubygems.org"

eval_gemfile "../gems.rb"

gem "async", "~> 1.0"
